@@ -1,5 +1,5 @@
 /*
- *  Copyright 2005-2012 Fabrice Colin
+ *  Copyright 2005-2022 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <iostream>
 #include <string>
 #include <fstream>
+#include <giomm/init.h>
 #include <glibmm.h>
 #include <glibmm/thread.h>
 #include <glibmm/miscutils.h>
@@ -158,7 +159,7 @@ static void printHelp(void)
 		<< "  -o, --override            MIME type detection override, as TYPE:EXT\n"
 		<< "  -s, --showinfo            show information about the document\n"
 		<< "  -v, --version             output version information and exit\n\n"
-		<< "Supported back-ends are :";
+		<< "Supported back-ends are:";
 	for (map<ModuleProperties, bool>::const_iterator engineIter = engines.begin(); engineIter != engines.end(); ++engineIter)
 	{
 		if ((engineIter->second == true) &&
@@ -170,7 +171,7 @@ static void printHelp(void)
 	ModuleFactory::unloadModules();
 	clog << "\n\nExamples:\n"
 		<< "pinot-index --check --showinfo --backend xapian --db ~/.pinot/daemon ../Bozo.txt\n\n"
-		<< "pinot-index --index --db PinotOnTheWeb http://code.google.com/p/pinot-search/\n\n"
+		<< "pinot-index --index --db Docs https://github.com/FabriceColin/pinot\n\n"
 		<< "pinot-index --index --db Docs --override text/x-rst:rst /usr/share/doc/python-kitchen-1.1.1/docs/index.rst\n\n"
 		<< "Indexing documents to My Web Pages or My Documents with pinot-index is not recommended\n\n"
 		<< "Report bugs to " << PACKAGE_BUGREPORT << endl;
@@ -276,6 +277,18 @@ int main(int argc, char **argv)
 	textdomain(GETTEXT_PACKAGE);
 #endif //ENABLE_NLS
 
+	Glib::init();
+	Gio::init();
+	// Initialize threads support before doing anything else
+	if (Glib::thread_supported() == false)
+	{
+		Glib::thread_init();
+	}
+	// Initialize GType
+#if !GLIB_CHECK_VERSION(2,35,0)
+	g_type_init();
+#endif
+
 	if (argc == 1)
 	{
 		printHelp();
@@ -297,18 +310,9 @@ int main(int argc, char **argv)
 		return EXIT_FAILURE;
 	}
 
-	// Initialize threads support before doing anything else
-	if (Glib::thread_supported() == false)
-	{
-		Glib::thread_init();
-	}
-
 	g_refMainLoop = Glib::MainLoop::create();
 	Glib::set_application_name("Pinot Indexer");
 
-	// This should make Xapian use Chert rather than Flint
-	Glib::setenv("XAPIAN_PREFER_CHERT", "1");
-
 	// This will create the necessary directories on the first run
 	PinotSettings &settings = PinotSettings::getInstance();
 	string confDirectory(PinotSettings::getConfigurationDirectory());
@@ -440,31 +444,29 @@ int main(int argc, char **argv)
 		DocumentInfo docInfo("", urlParam, MIMEScanner::scanUrl(thisUrl), "");
 		unsigned int docId = 0;
 
-		if (checkDocument == true)
+		if ((checkDocument == true) &&
+			(pIndex->isGood() == true))
 		{
-			if (pIndex->isGood() == true)
+			set<unsigned int> docIds;
+
+			docId = pIndex->hasDocument(urlParam);
+			if (docId > 0)
 			{
-				set<unsigned int> docIds;
+				clog << urlParam << ": document ID " << docId << endl;
+				success = true;
+			}
+			else if ((pIndex->listDocuments(urlParam, docIds, IndexInterface::BY_FILE, 100, 0) == true) &&
+				(docIds.empty() == false))
+			{
+				docId = *(docIds.begin());
 
-				docId = pIndex->hasDocument(urlParam);
-				if (docId > 0)
-				{
-					clog << urlParam << ": document ID " << docId << endl;
-					success = true;
-				}
-				else if ((pIndex->listDocuments(urlParam, docIds, IndexInterface::BY_FILE, 100, 0) == true) &&
-					(docIds.empty() == false))
-				{
-					docId = *(docIds.begin());
-
-					clog << urlParam << ": document ID " << docId
-						<< " and at least " << docIds.size() - 1 << " others" << endl;
-					success = true;
-				}
-				else
-				{
-					clog << urlParam << ": not found" << endl;
-				}
+				clog << urlParam << ": document ID " << docId
+					<< " and at least " << docIds.size() - 1 << " others" << endl;
+				success = true;
+			}
+			else
+			{
+				clog << urlParam << ": not found" << endl;
 			}
 		}
 		if (indexDocument == true)
@@ -502,16 +504,17 @@ int main(int argc, char **argv)
 		{
 			set<string> labels;
 
-			clog << "Index version       : " << pIndex->getMetadata("version") << endl;
+			clog << "Index version: " << pIndex->getMetadata("version") << endl;
 
 			if (pIndex->getDocumentInfo(docId, docInfo) == true)
 			{
-				clog << "Location : '" << docInfo.getLocation(true) << "'" << endl;
-				clog << "Title    : " << docInfo.getTitle() << endl;
-				clog << "Type     : " << docInfo.getType() << endl;
-				clog << "Language : " << docInfo.getLanguage() << endl;
-				clog << "Date     : " << docInfo.getTimestamp() << endl;
-				clog << "Size     : " << docInfo.getSize() << endl;
+				clog << "Document ID  : " << docId << endl;
+				clog << "Location     : '" << docInfo.getLocation(true) << "'" << endl;
+				clog << "Title        : " << docInfo.getTitle() << endl;
+				clog << "Type         : " << docInfo.getType() << endl;
+				clog << "Language     : " << docInfo.getLanguage() << endl;
+				clog << "Date         : " << docInfo.getTimestamp() << endl;
+				clog << "Size         : " << docInfo.getSize() << endl;
 			}
 			if (pIndex->getDocumentLabels(docId, labels) == true)
 			{
