@@ -1,5 +1,5 @@
 /*
- *  Copyright 2005-2015 Fabrice Colin
+ *  Copyright 2005-2022 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,6 +22,8 @@
 #include <iostream>
 #include <fstream>
 #include <string>
+#include <giomm/init.h>
+#include <glibmm/init.h>
 
 #include "config.h"
 #include "NLS.h"
@@ -69,7 +71,7 @@ static void printHelp(void)
 		<< "  -c, --tocsv               file to export results in CSV format to\n"
 		<< "  -x, --toxml               file to export results in XML format to\n"
 		<< "  -v, --version             output version information and exit\n"
-		<< "Supported search engine types are :";
+		<< "Supported search engine types are:";
 	for (map<ModuleProperties, bool>::const_iterator engineIter = engines.begin(); engineIter != engines.end(); ++engineIter)
 	{
 		clog << " '" << engineIter->first.m_name << "'";
@@ -77,7 +79,6 @@ static void printHelp(void)
 	clog << "\n\nExamples:\n"
 		<< "pinot-search opensearch " << PREFIX << "/share/pinot/engines/KrustyDescription.xml \"clowns\"\n\n"
 		<< "pinot-search --max 20 sherlock " << PREFIX << "/share/pinot/engines/Bozo.src \"clowns\"\n\n"
-		<< "pinot-search googleapi mygoogleapikey \"clowns\"\n\n"
 		<< "pinot-search xapian ~/.pinot/index \"label:Clowns\"\n\n"
 		<< "pinot-search --stemming english xapian somehostname:12345 \"clowning\"\n\n"
 		<< "Report bugs to " << PACKAGE_BUGREPORT << endl;
@@ -85,7 +86,6 @@ static void printHelp(void)
 
 int main(int argc, char **argv)
 {
-	QueryProperties::QueryType queryType = QueryProperties::XAPIAN_QP;
 	string engineType, option, csvExport, xmlExport, stemLanguage;
 	unsigned int maxResultsCount = 10; 
 	int longOptionIndex = 0;
@@ -158,6 +158,9 @@ int main(int argc, char **argv)
 	textdomain(GETTEXT_PACKAGE);
 #endif //ENABLE_NLS
 
+	Glib::init();
+	Gio::init();
+
 	if (argc == 1)
 	{
 		printHelp();
@@ -210,32 +213,29 @@ int main(int argc, char **argv)
 	char *pQueryInput = argv[optind + 2];
 
 	// Set the query
-	QueryProperties queryProps("pinot-search", "", queryType);
-	if (queryType == QueryProperties::XAPIAN_QP)
+	QueryProperties queryProps("pinot-search", "");
+	if (isStoredQuery == true)
 	{
-		if (isStoredQuery == true)
+		const map<string, QueryProperties> &queries = settings.getQueries();
+		map<string, QueryProperties>::const_iterator queryIter = queries.find(pQueryInput);
+		if (queryIter != queries.end())
 		{
-			const map<string, QueryProperties> &queries = settings.getQueries();
-			map<string, QueryProperties>::const_iterator queryIter = queries.find(pQueryInput);
-			if (queryIter != queries.end())
-			{
-				queryProps = queryIter->second;
-			}
-			else
-			{
-				clog << "Couldn't find stored query " << pQueryInput << endl;
-
-				DownloaderInterface::shutdown();
-				MIMEScanner::shutdown();
-
-				return EXIT_FAILURE;
-			}
+			queryProps = queryIter->second;
 		}
 		else
 		{
-			queryProps.setFreeQuery(pQueryInput);
+			clog << "Couldn't find stored query " << pQueryInput << endl;
+
+			DownloaderInterface::shutdown();
+			MIMEScanner::shutdown();
+
+			return EXIT_FAILURE;
 		}
 	}
+	else
+	{
+		queryProps.setFreeQuery(pQueryInput);
+	}
 	queryProps.setStemmingLanguage(stemLanguage);
 	queryProps.setMaximumResultsCount(maxResultsCount);
 	if (sortByDate == true)
