@@ -1,5 +1,5 @@
 /*
- *  Copyright 2005-2019 Fabrice Colin
+ *  Copyright 2005-2021 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -60,18 +60,6 @@ using std::pair;
 
 extern FieldMapperInterface *g_pMapper;
 
-static string removeCharsetFromType(const string &type)
-{
-	// Remove the charset, if any
-	string::size_type semiColonPos = type.find(";");
-	if (semiColonPos != string::npos)
-	{
-		return type.substr(0, semiColonPos);
-	}
-
-	return type;
-}
-
 class TokensIndexer : public Dijon::CJKVTokenizer::TokensHandler
 {
 	public:
@@ -160,7 +148,6 @@ class TokensIndexer : public Dijon::CJKVTokenizer::TokensHandler
 			// Is this CJKV ?
 			if (is_cjkv == false)
 			{
-#ifndef _DIACRITICS_SENSITIVE
 				bool hasDiacritics = false;
 
 				// Remove accents and other diacritics
@@ -170,7 +157,6 @@ class TokensIndexer : public Dijon::CJKVTokenizer::TokensHandler
 					m_doc.add_posting(m_prefix + XapianDatabase::limitTermLength(unaccentedTerm), m_termPos);
 					hasDiacritics = true;
 				}
-#endif
 
 				// Don't stem if the term starts with a digit
 				if ((m_pStemmer != NULL) &&
@@ -179,14 +165,12 @@ class TokensIndexer : public Dijon::CJKVTokenizer::TokensHandler
 					string stemmedTerm((*m_pStemmer)(term));
 
 					m_doc.add_term("Z" + XapianDatabase::limitTermLength(stemmedTerm));
-#ifndef _DIACRITICS_SENSITIVE
 					if (hasDiacritics == true)
 					{
 						stemmedTerm = (*m_pStemmer)(unaccentedTerm);
 
 						m_doc.add_term("Z" + XapianDatabase::limitTermLength(stemmedTerm));
 					}
-#endif
 				}
 
 				// Does it include dots ?
@@ -371,11 +355,11 @@ void XapianIndex::addPostingsToDocument(const Xapian::Utf8Iterator &itor, Xapian
 	Xapian::termcount &termPos) const
 {
 	Xapian::Stem *pStemmer = NULL;
-	bool isCJKV = false;
 
 	// Do we know what language to use for stemming ?
 	if ((noStemming == false) &&
-		(m_stemLanguage.empty() == false))
+		(m_stemLanguage.empty() == false) &&
+		(m_stemLanguage != "unknown"))
 	{
 		try
 		{
@@ -390,25 +374,14 @@ void XapianIndex::addPostingsToDocument(const Xapian::Utf8Iterator &itor, Xapian
 	const char *pRawData = itor.raw();
 	if (pRawData != NULL)
 	{
+#ifndef _TERM_GEN
 		Dijon::CJKVTokenizer tokenizer;
 		string text(pRawData);
 
-#ifdef _DIACRITICS_SENSITIVE
-		if (tokenizer.has_cjkv(text) == true)
-		{
-#endif
-			// Use overload
-			addPostingsToDocument(tokenizer, pStemmer, text, doc, db,
-				prefix, doSpelling, termPos);
-			isCJKV = true;
-#ifdef _DIACRITICS_SENSITIVE
-		}
-#endif
-	}
-
-#ifdef _DIACRITICS_SENSITIVE
-	if (isCJKV == false)
-	{
+		// Use overload
+		addPostingsToDocument(tokenizer, pStemmer, text, doc, db,
+			prefix, doSpelling, termPos);
+#else
 		Xapian::TermGenerator generator;
 
 		// Set the stemmer
@@ -446,8 +419,8 @@ void XapianIndex::addPostingsToDocument(const Xapian::Utf8Iterator &itor, Xapian
 			}
 		}
 		termPos = generator.get_termpos();
-	}
 #endif
+	}
 
 	if (pStemmer != NULL)
 	{
@@ -622,7 +595,7 @@ void XapianIndex::addCommonTerms(const DocumentInfo &docInfo, Xapian::Document &
 {
 	string title(docInfo.getTitle());
 	string location(docInfo.getLocation());
-	string type(removeCharsetFromType(docInfo.getType()));
+	string type(docInfo.getType(false));
 	Url urlObj(location);
 
 	// Add a magic term :-)
@@ -649,10 +622,14 @@ void XapianIndex::addCommonTerms(const DocumentInfo &docInfo, Xapian::Document &
 		tree = urlObj.getLocation();
 		fileName = urlObj.getFile();
 	}
+#ifdef DEBUG
+	clog << "XapianIndex::addCommonTerms: called for " << docInfo.getLocation()
+		<< " (" << docInfo.getInternalPath() << ")" << endl;
+#endif
 
 	// Index the full URL with prefix U
 	doc.add_term(string("U") + XapianDatabase::limitTermLength(Url::escapeUrl(docInfo.getLocation(true)), true));
-	// ...the base file with XFILE:
+	// And for containers, the base file with XFILE:
 	if ((urlObj.isLocal() == true) &&
 		(docInfo.getInternalPath().empty() == false))
 	{
@@ -685,15 +662,32 @@ void XapianIndex::addCommonTerms(const DocumentInfo &docInfo, Xapian::Document &
 	// ...the location (as is) and all directories with prefix XDIR:
 	if (tree.empty() == false)
 	{
+		if ((urlObj.isLocal() == true) &&
+			(docInfo.getIsDirectory() == true))
+		{
+			doc.add_term(string("XDIR:") + XapianDatabase::limitTermLength(Url::escapeUrl(docInfo.getLocation().substr(7)), true));
+#ifdef DEBUG
+			clog << "XapianIndex::addCommonTerms: full XDIR" << docInfo.getLocation().substr(7) << endl;
+#endif
+		}
 		doc.add_term(string("XDIR:") + XapianDatabase::limitTermLength(Url::escapeUrl(tree), true));
+#ifdef DEBUG
+		clog << "XapianIndex::addCommonTerms: first XDIR" << tree << endl;
+#endif
 		if (tree[0] == '/')
 		{
 			doc.add_term("XDIR:/");
+#ifdef DEBUG
+			clog << "XapianIndex::addCommonTerms: top-level XDIR" << endl;
+#endif
 		}
 		string::size_type slashPos = tree.find('/', 1);
 		while (slashPos != string::npos)
 		{
 			doc.add_term(string("XDIR:") + XapianDatabase::limitTermLength(Url::escapeUrl(tree.substr(0, slashPos)), true));
+#ifdef DEBUG
+			clog << "XapianIndex::addCommonTerms: component XDIR" << tree.substr(0, slashPos) << endl;
+#endif
 
 			// Next
 			slashPos = tree.find('/', slashPos + 1);
@@ -707,6 +701,9 @@ void XapianIndex::addCommonTerms(const DocumentInfo &docInfo, Xapian::Document &
 	else
 	{
 		doc.add_term("XDIR:/");
+#ifdef DEBUG
+		clog << "XapianIndex::addCommonTerms: single top-level XDIR" << endl;
+#endif
 	}
 	// ...and the file name with prefix P
 	if (fileName.empty() == false)
@@ -730,7 +727,7 @@ void XapianIndex::addCommonTerms(const DocumentInfo &docInfo, Xapian::Document &
 		{
 			extension = StringManip::toLowerCase(fileName.substr(extPos + 1));
 		}
-		doc.add_term(string("XEXT:") + XapianDatabase::limitTermLength(extension));
+		doc.add_term(string("E") + XapianDatabase::limitTermLength(extension));
 	}
 	// Add the language code with prefix L
 	doc.add_term(string("L") + Languages::toCode(m_stemLanguage));
@@ -787,7 +784,7 @@ void XapianIndex::removeCommonTerms(Xapian::Document &doc, const Xapian::Writabl
 	// Location 
 	string location(docInfo.getLocation());
 	commonTerms.insert(string("U") + XapianDatabase::limitTermLength(Url::escapeUrl(docInfo.getLocation(true)), true));
-	// Base file
+	// Containers' base file
 	if ((urlObj.isLocal() == true) &&
 		(docInfo.getInternalPath().empty() == false))
 	{
@@ -823,6 +820,11 @@ void XapianIndex::removeCommonTerms(Xapian::Document &doc, const Xapian::Writabl
 	string tree(urlObj.getLocation());
 	if (tree.empty() == false)
 	{
+		if ((urlObj.isLocal() == true) &&
+			(docInfo.getIsDirectory() == true))
+		{
+			commonTerms.insert(string("XDIR:") + XapianDatabase::limitTermLength(Url::escapeUrl(docInfo.getLocation().substr(7)), true));
+		}
 		commonTerms.insert(string("XDIR:") + XapianDatabase::limitTermLength(Url::escapeUrl(tree), true));
 		if (tree[0] == '/')
 		{
@@ -868,12 +870,12 @@ void XapianIndex::removeCommonTerms(Xapian::Document &doc, const Xapian::Writabl
 		{
 			extension = StringManip::toLowerCase(fileName.substr(extPos + 1));
 		}
-		commonTerms.insert(string("XEXT:") + XapianDatabase::limitTermLength(extension));
+		commonTerms.insert(string("E") + XapianDatabase::limitTermLength(extension));
 	}
 	// Language code
 	commonTerms.insert(string("L") + Languages::toCode(language));
 	// MIME type
-	string type(removeCharsetFromType(docInfo.getType()));
+	string type(docInfo.getType(false));
 	commonTerms.insert(string("T") + type);
 	string::size_type slashPos = type.find('/');
 	if (slashPos != string::npos)
@@ -1068,7 +1070,6 @@ bool XapianIndex::isGood(void) const
 /// Gets metadata.
 string XapianIndex::getMetadata(const string &name) const
 {
-#if ENABLE_XAPIAN_DB_METADATA>0
 	string metadataValue;
 
 	XapianDatabase *pDatabase = XapianDatabaseFactory::getDatabase(m_databaseName);
@@ -1099,15 +1100,11 @@ string XapianIndex::getMetadata(const string &name) const
 	pDatabase->unlock();
 
 	return metadataValue;
-#else
-	return "";
-#endif
 }
 
 /// Sets metadata.
 bool XapianIndex::setMetadata(const string &name, const string &value) const
 {
-#if ENABLE_XAPIAN_DB_METADATA>0
 	bool setMetadata = false;
 
 	XapianDatabase *pDatabase = XapianDatabaseFactory::getDatabase(m_databaseName, false);
@@ -1141,9 +1138,6 @@ bool XapianIndex::setMetadata(const string &name, const string &value) const
 	pDatabase->unlock();
 
 	return setMetadata;
-#else
-	return false;
-#endif
 }
 
 /// Gets the index location.
@@ -1376,7 +1370,18 @@ bool XapianIndex::getLabels(set<string> &labels) const
 /// Adds a label.
 bool XapianIndex::addLabel(const string &name)
 {
-	// Nothing to do here
+	set<string> labels;
+
+	if (getLabels(labels) == true)
+	{
+		labels.insert(name);
+
+		if (setLabels(labels, true) == true)
+		{
+			return true;
+		}
+	}
+
 	return false;
 }
 
@@ -1805,7 +1810,12 @@ unsigned int XapianIndex::listDocuments(set<unsigned int> &docIds,
 	unsigned int maxDocsCount, unsigned int startDoc) const
 {
 	// All documents have the magic term
-	return listDocumentsWithTerm("", docIds, maxDocsCount, startDoc);
+	if (listDocumentsWithTerm("", docIds, maxDocsCount, startDoc) == true)
+	{
+		return docIds.size();
+	}
+
+	return 0;
 }
 
 /// Lists documents.
@@ -1823,6 +1833,10 @@ bool XapianIndex::listDocuments(const string &name, set<unsigned int> &docIds,
 		term = string("XDIR:") + XapianDatabase::limitTermLength(Url::escapeUrl(name), true);
 	}
 	else if (type == BY_FILE)
+	{
+		term = string("U") + XapianDatabase::limitTermLength(Url::escapeUrl(name), true);
+	}
+	else if (type == BY_CONTAINER_FILE)
 	{
 		term = string("XFILE:") + XapianDatabase::limitTermLength(Url::escapeUrl(name), true);
 	}
@@ -1918,6 +1932,7 @@ bool XapianIndex::updateDocument(unsigned int docId, const Document &document)
 
 	// Cache the document's properties
 	DocumentInfo docInfo(document);
+	set<string> labels(document.getLabels());
 	docInfo.setLocation(Url::canonicalizeUrl(document.getLocation()));
 
 	off_t dataLength = 0;
@@ -1936,11 +1951,6 @@ bool XapianIndex::updateDocument(unsigned int docId, const Document &document)
 
 	try
 	{
-		set<string> labels;
-
-		// Get the document's labels
-		getDocumentLabels(docId, labels);
-
 		pIndex = pDatabase->writeLock();
 		if (pIndex != NULL)
 		{
@@ -2094,6 +2104,10 @@ bool XapianIndex::unindexDocuments(const string &name, NameType type)
 		term = string("XDIR:") + XapianDatabase::limitTermLength(Url::escapeUrl(name), true);
 	}
 	else if (type == BY_FILE)
+	{
+		term = string("U") + XapianDatabase::limitTermLength(Url::escapeUrl(name), true);
+	}
+	else if (type == BY_CONTAINER_FILE)
 	{
 		term = string("XFILE:") + XapianDatabase::limitTermLength(Url::escapeUrl(name), true);
 	}
@@ -2125,11 +2139,7 @@ bool XapianIndex::flush(void)
 		Xapian::WritableDatabase *pIndex = pDatabase->writeLock();
 		if (pIndex != NULL)
 		{
-#if XAPIAN_NUM_VERSION >= 1001000
 			pIndex->commit();
-#else
-			pIndex->flush();
-#endif
 			flushed = true;
 		}
 	}
