@@ -1,5 +1,5 @@
 /*
- *  Copyright 2005-2010 Fabrice Colin
+ *  Copyright 2005-2021 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -135,8 +135,6 @@ CrawlHistory::CrawlStatus CrawlHistory::textToStatus(const string &text)
 /// Creates the CrawlHistory table in the database.
 bool CrawlHistory::create(const string &database)
 {
-	bool createHistoryTable = false;
-
 	// The specified path must be a file
 	if (SQLiteBase::check(database) == false)
 	{
@@ -148,8 +146,8 @@ bool CrawlHistory::create(const string &database)
 	// Does CrawlSources exist ?
 	if (db.executeSimpleStatement("SELECT * FROM CrawlSources LIMIT 1;") == false)
 	{
-		if (db.executeSimpleStatement("CREATE TABLE CrawlSources (SourceID INTEGER \
-			PRIMARY KEY, Url VARCHAR(255));") == false)
+		if (db.executeSimpleStatement("CREATE TABLE CrawlSources (SourceID INTEGER "
+			"PRIMARY KEY, Url VARCHAR(255));") == false)
 		{
 			return false;
 		}
@@ -158,28 +156,8 @@ bool CrawlHistory::create(const string &database)
 	// Does CrawlHistory exist ?
 	if (db.executeSimpleStatement("SELECT * FROM CrawlHistory LIMIT 1;") == false)
 	{
-		createHistoryTable = true;
-	}
-	else
-	{
-		// Previous versions didn't include a ErrorNum field, so check for it
-		if (db.executeSimpleStatement("SELECT ErrorNum FROM CrawlHistory LIMIT 1;") == false)
-		{
-#ifdef DEBUG
-			clog << "CrawlHistory::create: CrawlHistory needs updating" << endl;
-#endif
-			// Ideally, we would use ALTER TABLE but it's not supported by SQLite
-			if (db.executeSimpleStatement("DROP TABLE CrawlHistory; VACUUM;") == true)
-			{
-				createHistoryTable = true;
-			}
-		}
-	}
-
-	if (createHistoryTable == true)
-	{
-		if (db.executeSimpleStatement("CREATE TABLE CrawlHistory (Url VARCHAR(255) PRIMARY KEY, \
-			Status VARCHAR(255), SourceID INTEGER, Date INTEGER, ErrorNum INTEGER);") == false)
+		if (db.executeSimpleStatement("CREATE TABLE CrawlHistory (Url VARCHAR(255) PRIMARY KEY, "
+			"Status VARCHAR(255), SourceID INTEGER, Date INTEGER, ErrorNum INTEGER);") == false)
 		{
 			return false;
 		}
@@ -196,14 +174,21 @@ unsigned int CrawlHistory::insertSource(const string &url)
 	SQLResults *results = executeStatement("SELECT MAX(SourceID) FROM CrawlSources;");
 	if (results != NULL)
 	{
-		sourceId = (unsigned int)results->getIntCount();
+		SQLRow *row = results->nextRow();
+		if (row != NULL)
+		{
+			sourceId = atoi(row->getColumn(0).c_str());
+
+			delete row;
+		}
+
 		++sourceId;
 
 		delete results;
 	}
 
-	results = executeStatement("INSERT INTO CrawlSources \
-		VALUES('%u', '%q');",
+	results = executeStatement("INSERT INTO CrawlSources "
+		"VALUES('%u', '%q');",
 		sourceId, Url::escapeUrl(url).c_str());
 	if (results != NULL)
 	{
@@ -213,7 +198,7 @@ unsigned int CrawlHistory::insertSource(const string &url)
 	return sourceId;
 }
 
-/// Checks if the source exists.
+/// Checks if a source exists.
 bool CrawlHistory::hasSource(const string &url, unsigned int &sourceId)
 {
 	vector<string> values;
@@ -224,8 +209,14 @@ bool CrawlHistory::hasSource(const string &url, unsigned int &sourceId)
 	SQLResults *results = executePreparedStatement("has-source", values);
 	if (results != NULL)
 	{
-		sourceId = (unsigned int)results->getIntCount();
-		success = true;
+		SQLRow *row = results->nextRow();
+		if (row != NULL)
+		{
+			sourceId = atoi(row->getColumn(0).c_str());
+			success = true;
+
+			delete row;
+		}
 
 		delete results;
 	}
@@ -267,8 +258,8 @@ bool CrawlHistory::deleteSource(unsigned int sourceId)
 {
 	bool success = false;
 
-	SQLResults *results = executeStatement("DELETE FROM CrawlSources \
-		WHERE SourceID='%u';", sourceId);
+	SQLResults *results = executeStatement("DELETE FROM CrawlSources "
+		"WHERE SourceID='%u';", sourceId);
 	if (results != NULL)
 	{
 		success = true;
@@ -295,10 +286,10 @@ bool CrawlHistory::insertItem(const string &url, CrawlStatus status, unsigned in
 	values.push_back(statusToText(status));
 	numStr << sourceId;
 	values.push_back(numStr.str());
-	numStr.clear();
+	numStr = stringstream();
 	numStr << date;
 	values.push_back(numStr.str());
-	numStr.clear();
+	numStr = stringstream();
 	numStr << errNum;
 	values.push_back(numStr.str());
 
@@ -354,7 +345,7 @@ bool CrawlHistory::updateItem(const string &url, CrawlStatus status, time_t date
 	values.push_back(statusToText(status));
 	numStr << date;
 	values.push_back(numStr.str());
-	numStr.clear();
+	numStr = stringstream();
 	numStr << errNum;
 	values.push_back(numStr.str());
 	values.push_back(Url::escapeUrl(url));
@@ -449,7 +440,8 @@ int CrawlHistory::getErrorDetails(const string &url, time_t &date)
 {
 	int errNum = 0;
 
-	SQLResults *results = executeStatement("SELECT ErrorNum, Date FROM CrawlHistory WHERE Url='%q';",
+	SQLResults *results = executeStatement("SELECT ErrorNum, Date "
+		"FROM CrawlHistory WHERE Url='%q';",
 		Url::escapeUrl(url).c_str());
 	if (results != NULL)
 	{
@@ -514,13 +506,13 @@ unsigned int CrawlHistory::getSourceItems(unsigned int sourceId, CrawlStatus sta
 	values.push_back(statusToText(status));
 	if (minDate > 0)
 	{
-		numStr.clear();
+		numStr = stringstream();
 		numStr << minDate;
 		values.push_back(numStr.str());
-		numStr.clear();
+		numStr = stringstream();
 		numStr << max - min;
 		values.push_back(numStr.str());
-		numStr.clear();
+		numStr = stringstream();
 		numStr << min;
 		values.push_back(numStr.str());
 
@@ -528,10 +520,10 @@ unsigned int CrawlHistory::getSourceItems(unsigned int sourceId, CrawlStatus sta
 	}
 	else
 	{
-		numStr.clear();
+		numStr = stringstream();
 		numStr << max - min;
 		values.push_back(numStr.str());
-		numStr.clear();
+		numStr = stringstream();
 		numStr << min;
 		values.push_back(numStr.str());
 
@@ -572,7 +564,13 @@ unsigned int CrawlHistory::getItemsCount(CrawlStatus status)
 	SQLResults *results = executePreparedStatement("get-items-count", values);
 	if (results != NULL)
 	{
-		count = (unsigned int)results->getIntCount();
+		SQLRow *row = results->nextRow();
+		if (row != NULL)
+		{
+			count = atoi(row->getColumn(0).c_str());
+
+			delete row;
+		}
 
 		delete results;
 	}
@@ -608,8 +606,9 @@ bool CrawlHistory::deleteItems(const string &url)
 		return false;
 	}
 
-	SQLResults *results = executeStatement("DELETE FROM CrawlHistory \
-		WHERE Url LIKE '%q%%';", Url::escapeUrl(url).c_str());
+	SQLResults *results = executeStatement("DELETE FROM CrawlHistory "
+		"WHERE Url LIKE '%q%%';",
+		Url::escapeUrl(url).c_str());
 	if (results != NULL)
 	{
 		success = true;
