@@ -1,5 +1,5 @@
 /*
- *  Copyright 2009-2011 Fabrice Colin
+ *  Copyright 2009-2024 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,6 +17,9 @@
  */
 
 #include "config.h"
+#ifdef HAVE_MALLINFO2
+#include <malloc.h>
+#else
 #ifdef HAVE_MALLINFO
 #include <malloc.h>
 #else
@@ -24,6 +27,7 @@
 #include <malloc.h>
 #endif
 #endif
+#endif
 
 #include "Memory.h"
 
@@ -82,6 +86,21 @@ int Memory::getUsage(void)
 
 #ifndef HAVE_UMEM_H
 	// All this only makes sense if umem isn't in use
+#ifdef HAVE_MALLINFO2
+	struct mallinfo2 info = mallinfo2();
+	/* arena: total space allocated from the heap (that is, how much the “break” point has moved since the start of the process).
+	 * uordblks:number of bytes allocated and in use.
+	 * fordblks:number of bytes allocated but not in use.
+	 * keepcost:size of the area that can be released with a malloc_trim ().
+	 * hblks:number of chunks allocated via mmap ().
+	 * hblkhd:total number of bytes allocated via mmap ().
+	 */
+	inUse = info.uordblks;
+#ifdef DEBUG
+	clog << "Memory::getUsage: allocated on the heap " << info.arena << ", mmap'ed " << info.hblkhd
+		<< ", in use " << inUse << ", not in use " << info.fordblks << ", can be trimmed " << info.keepcost << endl;
+#endif
+#else
 #ifdef HAVE_MALLINFO
 	struct mallinfo info = mallinfo();
 	/* arena: total space allocated from the heap (that is, how much the “break” point has moved since the start of the process).
@@ -97,6 +116,7 @@ int Memory::getUsage(void)
 		<< ", in use " << inUse << ", not in use " << info.fordblks << ", can be trimmed " << info.keepcost << endl;
 #endif
 #endif
+#endif
 #endif
 
 	return inUse;
